@@ -1,30 +1,14 @@
-/** ===========================================================
- *
- * This file is a part of KDE project
- *
- *
- * @date   2009-02-04
- * @brief  a command line tool to set IPTC Preview
- *
- * @author Copyright (C) 2009-2012 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    A command line tool to set IPTC Preview
+
+    SPDX-FileCopyrightText: 2009-2012 Gilles Caulier <caulier dot gilles at gmail dot com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Qt includes
 
-#include <QMatrix>
+#include <QTransform>
 #include <QImage>
 #include <QString>
 #include <QFile>
@@ -50,7 +34,7 @@ int main (int argc, char **argv)
     KExiv2  meta(filePath);
 
     QImage  image(filePath);
-    QMatrix matrix;
+    QTransform matrix;
     matrix.rotate(90);
     image = image.transformed(matrix);
 
